@@ -1,8 +1,10 @@
-# $Id: ErrorTest.pm 210 2006-05-23 18:58:57Z btrott $
+# $Id$
 
 package ErrorTest;
 use strict;
+use warnings;
 use base qw( Data::ObjectDriver::BaseObject );
+use DodTestUtil;
 
 use Data::ObjectDriver::Driver::DBI;
 
@@ -11,6 +13,6 @@ __PACKAGE__->install_properties({
     datasource => 'error_test',
     primary_key =>  [ ],
     driver => Data::ObjectDriver::Driver::DBI->new(
-        dsn      => 'dbi:SQLite:dbname=global.db',
+        dsn      => DodTestUtil::dsn('global'),
     ),
 });
