@@ -1,6 +1,8 @@
 # $Id: Wine.pm 1050 2005-12-08 13:46:22Z ykerherve $
 
 use strict;
+use warnings;
+use DodTestUtil;
 
 package PkLess;
 use base qw/Data::ObjectDriver::BaseObject/;
@@ -12,6 +14,6 @@ __PACKAGE__->install_properties({
     datasource => 'pkless',
     primary_key =>  [ ], # proper way to skip pk (for now XXX)
     driver => Data::ObjectDriver::Driver::DBI->new(
-        dsn      => 'dbi:SQLite:dbname=global.db',
+        dsn      => DodTestUtil::dsn('global'),
     ),
 });
