@@ -1,6 +1,8 @@
-# $Id: Wine.pm 344 2007-04-03 00:59:13Z ykerherve $
+# $Id$
 
 use strict;
+use warnings;
+use DodTestUtil;
 
 package My::BaseObject;
 use base qw/Data::ObjectDriver::BaseObject/;
@@ -24,7 +26,7 @@ __PACKAGE__->install_properties({
     primary_key => 'id',
     column_defs => { content => 'blob', binchar => 'binchar' },
     driver => Data::ObjectDriver::Driver::DBI->new(
-        dsn      => 'dbi:SQLite:dbname=global.db',
+        dsn      => DodTestUtil::dsn('global'),
     ),
 });
 
